@@ -1,7 +1,8 @@
 use crate::{
-	components::{
+	components::FuzzyFinderTarget,
+	popups::{
 		AppOption, BlameFileOpen, FileRevOpen, FileTreeOpen,
-		FuzzyFinderTarget, InspectCommitOpen,
+		InspectCommitOpen,
 	},
 	tabs::StashingOptions,
 };
@@ -34,8 +35,6 @@ bitflags! {
 pub struct ResetItem {
 	/// path to the item (folder/file)
 	pub path: String,
-	/// are talking about a folder here? otherwise it's a single file
-	pub is_folder: bool,
 }
 
 ///
@@ -54,6 +53,7 @@ pub enum Action {
 	AbortMerge,
 	AbortRebase,
 	AbortRevert,
+	UndoCommit,
 }
 
 #[derive(Debug)]
